@@ -2,13 +2,10 @@
 # vim: set et sts=2:
 # pylint: disable-msg=W0311,C0301,C0103,C0111,W0141,W0142
 
-
-import md5
 import logging
+import md5
 import multiprocessing
 import re
-from slapos.runner.process import Popen, isRunning, killRunningProcess
-from slapos.htpasswd import HtpasswdFile
 import shutil
 import os
 import time
@@ -18,6 +15,8 @@ from xml.dom import minidom
 import xml_marshaller
 from flask import jsonify
 
+from slapos.runner.process import Popen, isRunning, killRunningProcess
+from slapos.htpasswd import HtpasswdFile
 import slapos.slap
 
 # Setup default flask (werkzeug) parser
@@ -33,25 +32,22 @@ html_escape_table = {
   "<": "&lt;",
 }
 
+
 def html_escape(text):
   """Produce entities within text."""
   return "".join(html_escape_table.get(c, c) for c in text)
 
+
 def getSession(config):
   """
   Get the session data of current user.
   Returns:
-    a list of user information or False if fail to read data.
+    a list of user information or None if the file does not exist.
   """
   user_path = os.path.join(config['etc_dir'], '.users')
-  user = ""
   if os.path.exists(user_path):
-    f = open(user_path, 'r')
-    user = f.read().split(';')
-    f.close()
-  if type(user) == type(""):
-    return False
-  return user
+    return open(user_path).read().split(';')
+
 
 def saveSession(config, account):
   """
@@ -71,11 +67,9 @@ def saveSession(config, account):
   backup = False
   try:
     if os.path.exists(user):
-      f = open(user, 'r')
       #backup previous data
-      data = f.read()
-      open(user+'.back', 'w').write(data)
-      f.close()
+      data = open(user).read()
+      open('%s.back' % user, 'w').write(data)
       backup = True
       if not account[1]:
         account[1] = data.split(';')[1]
@@ -83,7 +77,7 @@ def saveSession(config, account):
     open(user, 'w').write((';'.join(account)).encode("utf-8"))
     # Htpasswd file for cloud9
     # XXX Cedric Le N order of account list values suppose to be fixed
-    # Remove former file to avoid aoutdated accounts
+    # Remove former file to avoid outdated accounts
     if os.path.exists(htpasswdfile):
       os.remove(htpasswdfile)
     passwd = HtpasswdFile(htpasswdfile, create=True)
@@ -94,11 +88,12 @@ def saveSession(config, account):
     try:
       if backup:
         os.remove(user)
-        os.rename(user+'.back', user)
+        os.rename('%s.back' % user, user)
     except:
       pass
     return str(e)
 
+
 def getCurrentSoftwareReleaseProfile(config):
   """
   Returns used Software Release profile as a string.
@@ -111,6 +106,7 @@ def getCurrentSoftwareReleaseProfile(config):
   except:
     return False
 
+
 def requestInstance(config, software_type=None):
   """
   Request the main instance of our environment
@@ -120,7 +116,7 @@ def requestInstance(config, software_type=None):
     # Write it to conf file for later use
     open(software_type_path, 'w').write(software_type)
   elif os.path.exists(software_type_path):
-    software_type = open(software_type_path, 'r').read()
+    software_type = open(software_type_path).read()
   else:
     software_type = 'default'
 
@@ -131,7 +127,7 @@ def requestInstance(config, software_type=None):
   param_path = os.path.join(config['etc_dir'], ".parameter.xml")
   xml_result = readParameters(param_path)
   partition_parameter_kw = None
-  if type(xml_result) != type('') and xml_result.has_key('instance'):
+  if type(xml_result) != type('') and 'instance' in xml_result:
     partition_parameter_kw = xml_result['instance']
 
   return slap.registerOpenOrder().request(
@@ -143,6 +139,7 @@ def requestInstance(config, software_type=None):
       state=None,
       shared=False)
 
+
 def updateProxy(config):
   """
   Configure Slapos Node computer and partitions.
@@ -158,30 +155,37 @@ def updateProxy(config):
   computer = slap.registerComputer(config['computer_id'])
   prefix = 'slappart'
   slap_config = {
- 'address': config['ipv4_address'],
- 'instance_root': config['instance_root'],
- 'netmask': '255.255.255.255',
- 'partition_list': [],
- 'reference': config['computer_id'],
- 'software_root': config['software_root']}
+    'address': config['ipv4_address'],
+    'instance_root': config['instance_root'],
+    'netmask': '255.255.255.255',
+    'partition_list': [],
+    'reference': config['computer_id'],
+    'software_root': config['software_root']
+  }
+
   for i in xrange(0, int(config['partition_amount'])):
     partition_reference = '%s%s' % (prefix, i)
     partition_path = os.path.join(config['instance_root'], partition_reference)
     if not os.path.exists(partition_path):
       os.mkdir(partition_path)
     os.chmod(partition_path, 0750)
-    slap_config['partition_list'].append({'address_list': [{'addr': config['ipv4_address'],
-                                       'netmask': '255.255.255.255'},
-                                      {'addr': config['ipv6_address'],
-                                       'netmask': 'ffff:ffff:ffff::'},
-                      ],
-                     'path': partition_path,
-                     'reference': partition_reference,
-                     'tap': {'name': partition_reference},
-                     })
+    slap_config['partition_list'].append({
+                                           'address_list': [
+                                              {
+                                                'addr': config['ipv4_address'],
+                                                'netmask': '255.255.255.255'
+                                              }, {
+                                                'addr': config['ipv6_address'],
+                                                'netmask': 'ffff:ffff:ffff::'
+                                              },
+                                           ],
+                                           'path': partition_path,
+                                           'reference': partition_reference,
+                                           'tap': {'name': partition_reference}})
   computer.updateConfiguration(xml_marshaller.xml_marshaller.dumps(slap_config))
   return True
 
+
 def updateInstanceParameter(config, software_type=None):
   """
   Reconfigure Slapproxy to re-deploy current Software Instance with parameters.
@@ -193,15 +197,18 @@ def updateInstanceParameter(config, software_type=None):
   if not (updateProxy(config) and requestInstance(config, software_type)):
     return False
 
+
 def startProxy(config):
   """Start Slapproxy server"""
-  if not isRunning('slapproxy'):
-    log = os.path.join(config['log_dir'], 'slapproxy.log')
-    Popen([config['slapproxy'], '--log_file', log,
-           config['configuration_file_path']],
-          name='slapproxy',
-          stdout=None)
-    time.sleep(4)
+  if isRunning('slapproxy'):
+    return
+
+  log = os.path.join(config['log_dir'], 'slapproxy.log')
+  Popen([config['slapproxy'], '--log_file', log,
+         config['configuration_file_path']],
+        name='slapproxy',
+        stdout=None)
+  time.sleep(4)
 
 
 def stopProxy(config):
@@ -210,15 +217,17 @@ def stopProxy(config):
 
 
 def removeProxyDb(config):
-  """Remove Slapproxy database, this is use to initialize proxy for example when
+  """Remove Slapproxy database, this is used to initialize proxy for example when
     configuring new Software Release"""
   if os.path.exists(config['database_uri']):
     os.unlink(config['database_uri'])
 
+
 def isSoftwareRunning(config=None):
   """
     Return True if slapgrid-sr is still running and false if slapgrid if not
   """
+  # XXX-Marco what is 'config' for?
   return isRunning('slapgrid-sr')
 
 
@@ -227,52 +236,55 @@ def runSoftwareWithLock(config):
     Use Slapgrid to compile current Software Release and wait until
     compilation is done
   """
+  if isSoftwareRunning():
+    return False
+
   slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-sr.pid')
-  if not isSoftwareRunning():
-    if not os.path.exists(config['software_root']):
-      os.mkdir(config['software_root'])
-    stopProxy(config)
-    removeProxyDb(config)
-    startProxy(config)
-    logfile = open(config['software_log'], 'w')
-    if not updateProxy(config):
-      return False
-    # Accelerate compilation by setting make -jX
-    environment = os.environ.copy()
-    environment['MAKEFLAGS'] = '-j%r' % multiprocessing.cpu_count()
-    slapgrid = Popen([config['slapgrid_sr'], '-vc',
-                      '--pidfile', slapgrid_pid,
-                      config['configuration_file_path'], '--now', '--develop'],
-                     stdout=logfile, env=environment,
-                     name='slapgrid-sr')
-    slapgrid.wait()
-    #Saves the current compile software for re-use
-    config_SR_folder(config)
-    return True
-  return False
+  if not os.path.exists(config['software_root']):
+    os.mkdir(config['software_root'])
+  stopProxy(config)
+  removeProxyDb(config)
+  startProxy(config)
+  logfile = open(config['software_log'], 'w')
+  if not updateProxy(config):
+    return False
+  # Accelerate compilation by setting make -jX
+  # XXX-Marco can have issues with implicit dependencies or recursive makefiles. should be configurable.
+  environment = os.environ.copy()
+  environment['MAKEFLAGS'] = '-j%r' % multiprocessing.cpu_count()
+  slapgrid = Popen([config['slapgrid_sr'], '-vc',
+                    '--pidfile', slapgrid_pid,
+                    config['configuration_file_path'], '--now', '--develop'],
+                   stdout=logfile, env=environment,
+                   name='slapgrid-sr')
+  slapgrid.wait()
+  #Saves the current compile software for re-use
+  config_SR_folder(config)
+  return True
+
 
 def config_SR_folder(config):
-  """Create a symbolik link for each folder in software folder. That allow
-    user to customize software release folder"""
+  """Create a symbolik link for each folder in software folder. That allows
+    the user to customize software release folder"""
   list = []
+  # XXX-Marco do not shadow 'list'
   config_name = 'slaprunner.config'
   for path in os.listdir(config['software_link']):
     cfg_path = os.path.join(config['software_link'], path, config_name)
     if os.path.exists(cfg_path):
-      cfg = open(cfg_path, 'r').read().split("#")
+      cfg = open(cfg_path).read().split("#")
       if len(cfg) != 2:
-        continue #there is a broken config file
+        continue  # there is a broken config file
       list.append(cfg[1])
   folder_list = os.listdir(config['software_root'])
-  if len(folder_list) < 1:
+  if not folder_list:
     return
-  curent_project = open(os.path.join(config['etc_dir'], ".project"),
-                        'r').read()
-  projects = curent_project.split("/")
-  name = projects[len(projects) - 2]
+  current_project = open(os.path.join(config['etc_dir'], ".project")).read()
+  projects = current_project.split('/')
+  name = projects[-2]
   for folder in folder_list:
     if folder in list:
-      continue #this folder is already registered
+      continue  # this folder is already registered
     else:
       if not os.path.exists(os.path.join(config['software_link'], name)):
         destination = os.path.join(config['software_link'], name)
@@ -283,9 +295,9 @@ def config_SR_folder(config):
       #create symlink
       os.symlink(source, destination)
       #write config file
-      cf = open(cfg, 'w')
-      cf.write(curent_project+"#"+folder)
-      cf.close()
+      with open(cfg, 'w') as cf:
+        cf.write(current_project + '#' + folder)
+
 
 def loadSoftwareRList(config):
   """Return list (of dict) of Software Release from symbolik SR folder"""
@@ -294,16 +306,18 @@ def loadSoftwareRList(config):
   for path in os.listdir(config['software_link']):
     cfg_path = os.path.join(config['software_link'], path, config_name)
     if os.path.exists(cfg_path):
-      cfg = open(cfg_path, 'r').read().split("#")
+      cfg = open(cfg_path).read().split("#")
       if len(cfg) != 2:
-        continue #there is a broken config file
+        continue  # there is a broken config file
       list.append(dict(md5=cfg[1], path=cfg[0], title=path))
   return list
 
+
 def isInstanceRunning(config=None):
   """
-    Return True if slapgrid-cp is still running and false if slapgrid if not
+    Return True if slapgrid-cp is still running and False otherwise
   """
+  # XXX-Marco what is 'config' for?
   return isRunning('slapgrid-cp')
 
 
@@ -312,19 +326,21 @@ def runInstanceWithLock(config):
     Use Slapgrid to deploy current Software Release and wait until
     deployment is done.
   """
+  if isInstanceRunning():
+    return False
+
   slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-cp.pid')
-  if not isInstanceRunning():
-    startProxy(config)
-    logfile = open(config['instance_log'], 'w')
-    if not (updateProxy(config) and requestInstance(config)):
-      return False
-    slapgrid = Popen([config['slapgrid_cp'], '-vc',
-                      '--pidfile', slapgrid_pid,
-                      config['configuration_file_path'], '--now'],
-                     stdout=logfile, name='slapgrid-cp')
-    slapgrid.wait()
-    return True
-  return False
+  startProxy(config)
+  logfile = open(config['instance_log'], 'w')
+  if not (updateProxy(config) and requestInstance(config)):
+    return False
+  slapgrid = Popen([config['slapgrid_cp'], '-vc',
+                    '--pidfile', slapgrid_pid,
+                    config['configuration_file_path'], '--now'],
+                   stdout=logfile, name='slapgrid-cp')
+  slapgrid.wait()
+  return True
+
 
 def getProfilePath(projectDir, profile):
   """
@@ -342,6 +358,7 @@ def getProfilePath(projectDir, profile):
   projectFolder = open(os.path.join(projectDir, ".project")).read()
   return os.path.join(projectFolder, profile)
 
+
 def getSlapStatus(config):
   """Return all Slapos Partitions with associate information"""
   slap = slapos.slap.slap()
@@ -361,23 +378,26 @@ def getSlapStatus(config):
         partition_list.append((slappart_id, []))
   return partition_list
 
+
 def svcStopAll(config):
-  """Stop all Instance process on this computer"""
+  """Stop all Instance processes on this computer"""
   return Popen([config['supervisor'], config['configuration_file_path'],
                 'shutdown']).communicate()[0]
 
+
 def removeInstanceRoot(config):
-  """Clean instance directory and stop all its running process"""
+  """Clean instance directory and stop all its running processes"""
   if os.path.exists(config['instance_root']):
     svcStopAll(config)
     for root, dirs, _ in os.walk(config['instance_root']):
       for fname in dirs:
         fullPath = os.path.join(root, fname)
-        if not os.access(fullPath, os.W_OK) :
+        if not os.access(fullPath, os.W_OK):
           # Some directories may be read-only, preventing to remove files in it
           os.chmod(fullPath, 0744)
     shutil.rmtree(config['instance_root'])
 
+
 def getSvcStatus(config):
   """Return all Softwares Instances process Information"""
   result = Popen([config['supervisor'], config['configuration_file_path'],
@@ -386,22 +406,24 @@ def getSvcStatus(config):
   supervisord = []
   for item in result.split('\n'):
     if item.strip() != "":
-      if re.search(regex, item, re.IGNORECASE) == None:
+      if re.search(regex, item, re.IGNORECASE) is None:
         supervisord.append(re.split('[\s,]+', item))
   return supervisord
 
+
 def getSvcTailProcess(config, process):
-  """Get log for the specifie process
+  """Get log for the specified process
 
   Args:
     config: Slaprunner configuration
-    process: process name. this value is pass to supervisord.
+    process: process name. this value is passed to supervisord.
   Returns:
     a string that contains the log of the process.
   """
   return Popen([config['supervisor'], config['configuration_file_path'],
                 "tail", process]).communicate()[0]
 
+
 def svcStartStopProcess(config, process, action):
   """Send start or stop process command to supervisord
 
@@ -410,10 +432,17 @@ def svcStartStopProcess(config, process, action):
     process: process to start or stop.
     action: current state which is used to generate the new process state.
   """
-  cmd = {"RESTART":"restart", "STOPPED":"start", "RUNNING":"stop", "EXITED":"start", "STOP":"stop"}
+  cmd = {
+    'RESTART': 'restart',
+    'STOPPED': 'start',
+    'RUNNING': 'stop',
+    'EXITED': 'start',
+    'STOP': 'stop'
+  }
   return Popen([config['supervisor'], config['configuration_file_path'],
                 cmd[action], process]).communicate()[0]
 
+
 def getFolderContent(config, folder):
   """
   Read all file and folder into specified directory
@@ -423,7 +452,7 @@ def getFolderContent(config, folder):
     folder: the directory to read.
 
   Returns:
-    Html formated string or error message when fail.
+    Html formatted string or error message when fail.
   """
   r = ['<ul class="jqueryFileTree" style="display: none;">']
   try:
@@ -431,19 +460,20 @@ def getFolderContent(config, folder):
     r = ['<ul class="jqueryFileTree" style="display: none;">']
     d = urllib.unquote(folder)
     realdir = realpath(config, d)
-    if not realdir:
+    if realdir:
+      ldir = sorted(os.listdir(realdir), key=str.lower)
+    else:
       r.append('Could not load directory: Permission denied')
       ldir = []
-    else:
-      ldir = sorted(os.listdir(realdir), key=str.lower)
+
     for f in ldir:
-      if f.startswith('.'): #do not displays this file/folder
+      if f.startswith('.'):  # do not displays this file/folder
         continue
       ff = os.path.join(d, f)
       if os.path.isdir(os.path.join(realdir, f)):
         r.append('<li class="directory collapsed"><a href="#%s" rel="%s/">%s</a></li>' % (ff, ff, f))
       else:
-        e = os.path.splitext(f)[1][1:] # get .ext and remove dot
+        e = os.path.splitext(f)[1][1:]  # get .ext and remove dot
         r.append('<li class="file ext_%s"><a href="#%s" rel="%s">%s</a></li>' % (e, ff, ff, f))
     r.append('</ul>')
   except Exception as e:
@@ -451,6 +481,7 @@ def getFolderContent(config, folder):
   r.append('</ul>')
   return jsonify(result=''.join(r))
 
+
 def getFolder(config, folder):
   """
   Read list of folder for the specified directory
@@ -460,7 +491,7 @@ def getFolder(config, folder):
     folder: the directory to read.
 
   Returns:
-    Html formated string or error message when fail.
+    Html formatted string or error message when fail.
   """
   r = ['<ul class="jqueryFileTree" style="display: none;">']
   try:
@@ -474,7 +505,7 @@ def getFolder(config, folder):
     else:
       ldir = sorted(os.listdir(realdir), key=str.lower)
     for f in ldir:
-      if f.startswith('.'): #do not display this file/folder
+      if f.startswith('.'):  # do not display this file/folder
         continue
       ff = os.path.join(d, f)
       if os.path.isdir(os.path.join(realdir, f)):
@@ -485,6 +516,7 @@ def getFolder(config, folder):
   r.append('</ul>')
   return jsonify(result=''.join(r))
 
+
 def getProjectList(folder):
   """Return the list of projet (folder) into the workspace
 
@@ -500,6 +532,7 @@ def getProjectList(folder):
       project.append(elt)
   return project
 
+
 def configNewSR(config, projectpath):
   """Configure a Software Release as current Software Release
 
@@ -527,6 +560,7 @@ def configNewSR(config, projectpath):
   else:
     return False
 
+
 def newSoftware(folder, config, session):
   """
   Create a new Software Release folder with default profiles
@@ -562,14 +596,14 @@ def newSoftware(folder, config, session):
       session['title'] = getProjectTitle(config)
       code = 1
     else:
-      json = "Bad folder or Directory '" + folder + \
-        "' already exist, please enter a new name for your software"
+      json = "Bad folder or Directory '%s' already exist, please enter a new name for your software" % folder
   except Exception as e:
-    json = "Can not create your software, please try again! : " + str(e)
+    json = "Can not create your software, please try again! : %s " % e
     if os.path.exists(folderPath):
       shutil.rmtree(folderPath)
   return jsonify(code=code, result=json)
 
+
 def checkSoftwareFolder(path, config):
   """Check id `path` is a valid Software Release folder"""
   realdir = realpath(config, path)
@@ -577,6 +611,7 @@ def checkSoftwareFolder(path, config):
     return jsonify(result=path)
   return jsonify(result="")
 
+
 def getProjectTitle(config):
   """Generate the name of the current software Release (for slaprunner UI)"""
   conf = os.path.join(config['etc_dir'], ".project")
@@ -586,6 +621,7 @@ def getProjectTitle(config):
     return '%s (%s)' % (software, '/'.join(project[:-2]))
   return "No Profile"
 
+
 def getSoftwareReleaseName(config):
   """Get the name of the current Software Release"""
   sr_profile = os.path.join(config['etc_dir'], ".project")
@@ -595,6 +631,7 @@ def getSoftwareReleaseName(config):
     return software.replace(' ', '_')
   return "No_name"
 
+
 def removeSoftwareByName(config, md5, folderName):
   """Remove all content of the software release specified by md5
 
@@ -610,12 +647,13 @@ def removeSoftwareByName(config, md5, folderName):
     raise Exception("Cannot remove software Release: No such file or directory")
   if not os.path.exists(linkpath):
     raise Exception("Cannot remove software Release: No such file or directory %s" %
-                    ('software_root/'+folderName))
+                    ('software_root/' + folderName))
   svcStopAll(config)
   os.unlink(linkpath)
   shutil.rmtree(path)
   return loadSoftwareRList(config)
 
+
 def tail(f, lines=20):
   """
   Returns the last `lines` lines of file `f`. It is an implementation of tail -f n.
@@ -643,30 +681,32 @@ def tail(f, lines=20):
       block -= 1
   return '\n'.join(''.join(data).splitlines()[-lines:])
 
+
 def readFileFrom(f, lastPosition, limit=20000):
   """
   Returns the last lines of file `f`, from position lastPosition.
   and the last position
-  limit = max number of caracter to read
+  limit = max number of characters to read
   """
   BUFSIZ = 1024
   f.seek(0, 2)
+  # XXX-Marco do now shadow 'bytes'
   bytes = f.tell()
   block = -1
   data = ""
   length = bytes
-  truncated = False #True if a part of log data has been truncated
-  if (lastPosition <= 0 and length > limit) or (length-lastPosition > limit):
+  truncated = False  # True if a part of log data has been truncated
+  if (lastPosition <= 0 and length > limit) or (length - lastPosition > limit):
     lastPosition = length - limit
     truncated = True
   size = bytes - lastPosition
   while bytes > lastPosition:
-    if abs(block*BUFSIZ) <= size:
+    if abs(block * BUFSIZ) <= size:
       # Seek back one whole BUFSIZ
       f.seek(block * BUFSIZ, 2)
       data = f.read(BUFSIZ) + data
     else:
-      margin = abs(block*BUFSIZ) - size
+      margin = abs(block * BUFSIZ) - size
       if length < BUFSIZ:
         f.seek(0, 0)
       else:
@@ -676,7 +716,12 @@ def readFileFrom(f, lastPosition, limit=20000):
     bytes -= BUFSIZ
     block -= 1
   f.close()
-  return {"content":data, "position":length, "truncated":truncated}
+  return {
+    'content': data,
+    'position': length,
+    'truncated': truncated
+  }
+
 
 def isText(file):
   """Return True if the mimetype of file is Text"""
@@ -689,8 +734,10 @@ def isText(file):
   except:
     return False
 
+
 def md5sum(file):
   """Compute md5sum of `file` and return hexdigest value"""
+  # XXX-Marco: returning object or False boolean is an anti-pattern. better to return object or None
   if os.path.isdir(file):
     return False
   try:
@@ -705,6 +752,7 @@ def md5sum(file):
   except:
     return False
 
+
 def realpath(config, path, check_exist=True):
   """
   Get realpath of path or return False if user is not allowed to access to
@@ -712,20 +760,25 @@ def realpath(config, path, check_exist=True):
   """
   split_path = path.split('/')
   key = split_path[0]
-  allow_list = {'software_root':config['software_root'], 'instance_root':
-                config['instance_root'], 'workspace': config['workspace'],
-                'software_link':config['software_link']}
-  if allow_list.has_key(key):
-    del split_path[0]
-    path = os.path.join(allow_list[key], *split_path)
-    if check_exist:
-      if os.path.exists(path):
-        return path
-      else:
-        return False
-    else:
+  allow_list = {
+    'software_root': config['software_root'],
+    'instance_root': config['instance_root'],
+    'workspace': config['workspace'],
+    'software_link': config['software_link']
+  }
+  if key not in allow_list:
+    return False
+
+  del split_path[0]
+  path = os.path.join(allow_list[key], *split_path)
+  if check_exist:
+    if os.path.exists(path):
       return path
-  return False
+    else:
+      return False
+  else:
+    return path
+
 
 def readParameters(path):
   """Read Instance parameters stored into a local file.
@@ -734,7 +787,7 @@ def readParameters(path):
     path: path of the xml file that contains parameters
 
   Return:
-    a dictionnary of instance parameters."""
+    a dictionary of instance parameters."""
   if os.path.exists(path):
     try:
       xmldoc = minidom.parse(path)
@@ -743,10 +796,10 @@ def readParameters(path):
         sub_obj = {}
         for subnode in elt.childNodes:
           if subnode.nodeType != subnode.TEXT_NODE:
-            sub_obj[str(subnode.getAttribute('id'))] = subnode.childNodes[0].data #.decode('utf-8').decode('utf-8')
+            sub_obj[str(subnode.getAttribute('id'))] = subnode.childNodes[0].data  # .decode('utf-8').decode('utf-8')
             obj[str(elt.tagName)] = sub_obj
       return obj
     except Exception, e:
       return str(e)
   else:
-    return "No such file or directory: " + path
+    return "No such file or directory: %s" % path
